=== modified file 'bzrlib/smart/__init__.py'
--- bzrlib/smart/__init__.py	2007-04-06 01:19:30 +0000
+++ bzrlib/smart/__init__.py	2007-04-10 02:31:42 +0000
@@ -16,6 +16,13 @@
 
 """Smart-server protocol, client and server.
 
+This code is fairly complex, so it has been split up into a package of modules,
+rather than being a single large module.  Refer to the individual module
+docstrings for details.
+
+Overview
+========
+
 Requests are sent as a command and list of arguments, followed by optional
 bulk body data.  Responses are similarly a response and list of arguments,
 followed by bulk body data. ::

=== modified file 'bzrlib/smart/medium.py'
--- bzrlib/smart/medium.py	2007-04-09 04:49:55 +0000
+++ bzrlib/smart/medium.py	2007-04-10 02:31:42 +0000
@@ -37,169 +37,6 @@
     pass
 
 
-class SmartClientMediumRequest(object):
-    """A request on a SmartClientMedium.
-
-    Each request allows bytes to be provided to it via accept_bytes, and then
-    the response bytes to be read via read_bytes.
-
-    For instance:
-    request.accept_bytes('123')
-    request.finished_writing()
-    result = request.read_bytes(3)
-    request.finished_reading()
-
-    It is up to the individual SmartClientMedium whether multiple concurrent
-    requests can exist. See SmartClientMedium.get_request to obtain instances 
-    of SmartClientMediumRequest, and the concrete Medium you are using for 
-    details on concurrency and pipelining.
-    """
-
-    def __init__(self, medium):
-        """Construct a SmartClientMediumRequest for the medium medium."""
-        self._medium = medium
-        # we track state by constants - we may want to use the same
-        # pattern as BodyReader if it gets more complex.
-        # valid states are: "writing", "reading", "done"
-        self._state = "writing"
-
-    def accept_bytes(self, bytes):
-        """Accept bytes for inclusion in this request.
-
-        This method may not be be called after finished_writing() has been
-        called.  It depends upon the Medium whether or not the bytes will be
-        immediately transmitted. Message based Mediums will tend to buffer the
-        bytes until finished_writing() is called.
-
-        :param bytes: A bytestring.
-        """
-        if self._state != "writing":
-            raise errors.WritingCompleted(self)
-        self._accept_bytes(bytes)
-
-    def _accept_bytes(self, bytes):
-        """Helper for accept_bytes.
-
-        Accept_bytes checks the state of the request to determing if bytes
-        should be accepted. After that it hands off to _accept_bytes to do the
-        actual acceptance.
-        """
-        raise NotImplementedError(self._accept_bytes)
-
-    def finished_reading(self):
-        """Inform the request that all desired data has been read.
-
-        This will remove the request from the pipeline for its medium (if the
-        medium supports pipelining) and any further calls to methods on the
-        request will raise ReadingCompleted.
-        """
-        if self._state == "writing":
-            raise errors.WritingNotComplete(self)
-        if self._state != "reading":
-            raise errors.ReadingCompleted(self)
-        self._state = "done"
-        self._finished_reading()
-
-    def _finished_reading(self):
-        """Helper for finished_reading.
-
-        finished_reading checks the state of the request to determine if 
-        finished_reading is allowed, and if it is hands off to _finished_reading
-        to perform the action.
-        """
-        raise NotImplementedError(self._finished_reading)
-
-    def finished_writing(self):
-        """Finish the writing phase of this request.
-
-        This will flush all pending data for this request along the medium.
-        After calling finished_writing, you may not call accept_bytes anymore.
-        """
-        if self._state != "writing":
-            raise errors.WritingCompleted(self)
-        self._state = "reading"
-        self._finished_writing()
-
-    def _finished_writing(self):
-        """Helper for finished_writing.
-
-        finished_writing checks the state of the request to determine if 
-        finished_writing is allowed, and if it is hands off to _finished_writing
-        to perform the action.
-        """
-        raise NotImplementedError(self._finished_writing)
-
-    def read_bytes(self, count):
-        """Read bytes from this requests response.
-
-        This method will block and wait for count bytes to be read. It may not
-        be invoked until finished_writing() has been called - this is to ensure
-        a message-based approach to requests, for compatability with message
-        based mediums like HTTP.
-        """
-        if self._state == "writing":
-            raise errors.WritingNotComplete(self)
-        if self._state != "reading":
-            raise errors.ReadingCompleted(self)
-        return self._read_bytes(count)
-
-    def _read_bytes(self, count):
-        """Helper for read_bytes.
-
-        read_bytes checks the state of the request to determing if bytes
-        should be read. After that it hands off to _read_bytes to do the
-        actual read.
-        """
-        raise NotImplementedError(self._read_bytes)
-
-
-class SmartClientStreamMediumRequest(SmartClientMediumRequest):
-    """A SmartClientMediumRequest that works with an SmartClientStreamMedium."""
-
-    def __init__(self, medium):
-        SmartClientMediumRequest.__init__(self, medium)
-        # check that we are safe concurrency wise. If some streams start
-        # allowing concurrent requests - i.e. via multiplexing - then this
-        # assert should be moved to SmartClientStreamMedium.get_request,
-        # and the setting/unsetting of _current_request likewise moved into
-        # that class : but its unneeded overhead for now. RBC 20060922
-        if self._medium._current_request is not None:
-            raise errors.TooManyConcurrentRequests(self._medium)
-        self._medium._current_request = self
-
-    def _accept_bytes(self, bytes):
-        """See SmartClientMediumRequest._accept_bytes.
-        
-        This forwards to self._medium._accept_bytes because we are operating
-        on the mediums stream.
-        """
-        self._medium._accept_bytes(bytes)
-
-    def _finished_reading(self):
-        """See SmartClientMediumRequest._finished_reading.
-
-        This clears the _current_request on self._medium to allow a new 
-        request to be created.
-        """
-        assert self._medium._current_request is self
-        self._medium._current_request = None
-        
-    def _finished_writing(self):
-        """See SmartClientMediumRequest._finished_writing.
-
-        This invokes self._medium._flush to ensure all bytes are transmitted.
-        """
-        self._medium._flush()
-
-    def _read_bytes(self, count):
-        """See SmartClientMediumRequest._read_bytes.
-        
-        This forwards to self._medium._read_bytes because we are operating
-        on the mediums stream.
-        """
-        return self._medium._read_bytes(count)
-
-
 class SmartServerStreamMedium(object):
     """Handles smart commands coming over a stream.
 
@@ -336,6 +173,122 @@
         self._out.write(bytes)
 
 
+class SmartClientMediumRequest(object):
+    """A request on a SmartClientMedium.
+
+    Each request allows bytes to be provided to it via accept_bytes, and then
+    the response bytes to be read via read_bytes.
+
+    For instance:
+    request.accept_bytes('123')
+    request.finished_writing()
+    result = request.read_bytes(3)
+    request.finished_reading()
+
+    It is up to the individual SmartClientMedium whether multiple concurrent
+    requests can exist. See SmartClientMedium.get_request to obtain instances 
+    of SmartClientMediumRequest, and the concrete Medium you are using for 
+    details on concurrency and pipelining.
+    """
+
+    def __init__(self, medium):
+        """Construct a SmartClientMediumRequest for the medium medium."""
+        self._medium = medium
+        # we track state by constants - we may want to use the same
+        # pattern as BodyReader if it gets more complex.
+        # valid states are: "writing", "reading", "done"
+        self._state = "writing"
+
+    def accept_bytes(self, bytes):
+        """Accept bytes for inclusion in this request.
+
+        This method may not be be called after finished_writing() has been
+        called.  It depends upon the Medium whether or not the bytes will be
+        immediately transmitted. Message based Mediums will tend to buffer the
+        bytes until finished_writing() is called.
+
+        :param bytes: A bytestring.
+        """
+        if self._state != "writing":
+            raise errors.WritingCompleted(self)
+        self._accept_bytes(bytes)
+
+    def _accept_bytes(self, bytes):
+        """Helper for accept_bytes.
+
+        Accept_bytes checks the state of the request to determing if bytes
+        should be accepted. After that it hands off to _accept_bytes to do the
+        actual acceptance.
+        """
+        raise NotImplementedError(self._accept_bytes)
+
+    def finished_reading(self):
+        """Inform the request that all desired data has been read.
+
+        This will remove the request from the pipeline for its medium (if the
+        medium supports pipelining) and any further calls to methods on the
+        request will raise ReadingCompleted.
+        """
+        if self._state == "writing":
+            raise errors.WritingNotComplete(self)
+        if self._state != "reading":
+            raise errors.ReadingCompleted(self)
+        self._state = "done"
+        self._finished_reading()
+
+    def _finished_reading(self):
+        """Helper for finished_reading.
+
+        finished_reading checks the state of the request to determine if 
+        finished_reading is allowed, and if it is hands off to _finished_reading
+        to perform the action.
+        """
+        raise NotImplementedError(self._finished_reading)
+
+    def finished_writing(self):
+        """Finish the writing phase of this request.
+
+        This will flush all pending data for this request along the medium.
+        After calling finished_writing, you may not call accept_bytes anymore.
+        """
+        if self._state != "writing":
+            raise errors.WritingCompleted(self)
+        self._state = "reading"
+        self._finished_writing()
+
+    def _finished_writing(self):
+        """Helper for finished_writing.
+
+        finished_writing checks the state of the request to determine if 
+        finished_writing is allowed, and if it is hands off to _finished_writing
+        to perform the action.
+        """
+        raise NotImplementedError(self._finished_writing)
+
+    def read_bytes(self, count):
+        """Read bytes from this requests response.
+
+        This method will block and wait for count bytes to be read. It may not
+        be invoked until finished_writing() has been called - this is to ensure
+        a message-based approach to requests, for compatability with message
+        based mediums like HTTP.
+        """
+        if self._state == "writing":
+            raise errors.WritingNotComplete(self)
+        if self._state != "reading":
+            raise errors.ReadingCompleted(self)
+        return self._read_bytes(count)
+
+    def _read_bytes(self, count):
+        """Helper for read_bytes.
+
+        read_bytes checks the state of the request to determing if bytes
+        should be read. After that it hands off to _read_bytes to do the
+        actual read.
+        """
+        raise NotImplementedError(self._read_bytes)
+
+
 class SmartClientMedium(object):
     """Smart client is a medium for sending smart protocol requests over."""
 
@@ -523,3 +476,51 @@
             raise errors.MediumNotConnected(self)
         return self._socket.recv(count)
 
+
+class SmartClientStreamMediumRequest(SmartClientMediumRequest):
+    """A SmartClientMediumRequest that works with an SmartClientStreamMedium."""
+
+    def __init__(self, medium):
+        SmartClientMediumRequest.__init__(self, medium)
+        # check that we are safe concurrency wise. If some streams start
+        # allowing concurrent requests - i.e. via multiplexing - then this
+        # assert should be moved to SmartClientStreamMedium.get_request,
+        # and the setting/unsetting of _current_request likewise moved into
+        # that class : but its unneeded overhead for now. RBC 20060922
+        if self._medium._current_request is not None:
+            raise errors.TooManyConcurrentRequests(self._medium)
+        self._medium._current_request = self
+
+    def _accept_bytes(self, bytes):
+        """See SmartClientMediumRequest._accept_bytes.
+        
+        This forwards to self._medium._accept_bytes because we are operating
+        on the mediums stream.
+        """
+        self._medium._accept_bytes(bytes)
+
+    def _finished_reading(self):
+        """See SmartClientMediumRequest._finished_reading.
+
+        This clears the _current_request on self._medium to allow a new 
+        request to be created.
+        """
+        assert self._medium._current_request is self
+        self._medium._current_request = None
+        
+    def _finished_writing(self):
+        """See SmartClientMediumRequest._finished_writing.
+
+        This invokes self._medium._flush to ensure all bytes are transmitted.
+        """
+        self._medium._flush()
+
+    def _read_bytes(self, count):
+        """See SmartClientMediumRequest._read_bytes.
+        
+        This forwards to self._medium._read_bytes because we are operating
+        on the mediums stream.
+        """
+        return self._medium._read_bytes(count)
+
+

